<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Message;
use App\Models\Appointment;
use App\Models\Order;
use App\Models\User;
use App\Models\Prescription;
use Illuminate\Support\Facades\Cache;
use Barryvdh\DomPDF\Facade\Pdf;

class AdminController extends Controller
{
    public function index()
    {
//    $cachedViewData = Cache::get('admin_index_data');

//    if ($cachedViewData) {
//        return view('admin.index')->with('viewData', $cachedViewData);
//    }

   $messagesCount = Message::count();
   $appointmentsCount = Appointment::count();
   $ordersCount = Order::count();
   $usersCount = User::count();

   $viewData = [
       'messagesCount' => $messagesCount,
       'appointmentsCount' => $appointmentsCount,
       'ordersCount' => $ordersCount,
       'usersCount' => $usersCount,
   ];

  

   return view('admin.index')->with('viewData', $viewData);


/**=======orders function========== */ 
    }
    public function orders(){

    
            $orders = Order::with('user')->get();
            $viewData = [
                'orders' => $orders,
            ];
    
      return view('admin.orders.index')->with('viewData', $viewData);
    }


/**=======appointments function========== */ 
    public function appointments(){

        $appointments = Appointment::with('user')->get();
        $viewData = [
            'appointments' => $appointments,
        ];

        return view('admin.appointments.index')->with('viewData', $viewData);
    }


/**=======messages function========== */ 
    public function messages(){

        $messages = Message::with('sender')->get();
        $viewData = [
            'messages' => $messages,
        ];

        return view('admin.messages.index')->with('viewData', $viewData);  
    }


/**=======users function========== */ 
    public function users(){

        $users = User::all();
        $viewData = [
            'users' => $users,
        ];

        return view('admin.users.index')->with('viewData', $viewData);
    }
public function showUser($id)
{
    $user = User::with('orders', 'appointments')->findOrFail($id);
    return view('admin.users.show', compact('user'));
}

/**=======prescriptions function========== */ 
public function prescriptions(){

    $prescriptions = Prescription::with('user')->get();
    $viewData = [
        'prescriptions' => $prescriptions,
    ];
    return view('admin.prescriptions.index')->with('viewData', $viewData);
}


/**=======edit orders function========== */ 
/**=======TODO Create Logic for Orders========== */
public function editOrder($id)
{
    $order = Order::findOrFail($id);
    return view('admin.orders.edit', compact('order'));
}
public function updateOrder(Request $request, $id)
{
    $request->validate([
        'location' => 'required',
        'quantity' => 'required',

    ]);


    $order = Order::findOrFail($id);
    $order->update($request->all());
    return redirect()->route('admin.orders.index');
}

/**=======edit appointments function========== */ 
public function editAppointment($id)
{
    $appointment = Appointment::findOrFail($id);
    return view('admin.appointments.edit', compact('appointment'));
}
public function updateAppointment(Request $request, $id)
{
    $request->validate([
        'input_date' => 'required',
        'radio_selection' => 'required|in:8:00 AM,10:00 AM,12:00 PM,2:00 PM,4:00 PM',
    ]);
    $appointment = Appointment::findOrFail($id);
    $appointment->update($request->all());
    return redirect()->route('admin.appointments.index');
}
/**=======edit messages function========== */ 
public function editMessage($id)
{
    $message = Message::findOrFail($id);
    return view('admin.messages.edit', compact('message'));
}
public function updateMessage(Request $request, $id)
{
    $request->validate([
        'subject' => 'required|string|max:255',
        'content' => 'required|string',
        ]);

        $message = Message::findOrFail($id);
        $message->update($request->all());
        return redirect()->route('admin.messages.index');
    }

/**=======edit users function========== */ 
public function editUser($id)
{
    $user = User::findOrFail($id);
    return view('admin.users.edit', compact('user'));
}
public function updateUser(Request $request, $id)
{
   $request->validate([
        'name' => 'required|string|max:255',
        'email' => 'required|string|email|max:255',
    ]);
    $user = User::findOrFail($id);
    $user->update($request->all());
    return redirect()->route('admin.users.update');
}

/**=======edit prescription function========== */
public function editPrescription($id){
    $prescription = Prescription::findOrFail($id);
    return view('admin.prescriptions.edit', compact('prescription'));
}
public function updatePrescription(Request $request, $id){
    $request->validate([
        'medication' => 'required|string|max:255',
        'instructions' => 'required|string',
        'dosage' => 'required|string',
        'frequency' => 'required|string',
        
    ]);
    $prescription = Prescription::findOrFail($id);
    $prescription->update($request->all());
    return redirect()->route('admin.prescriptions.index');
}




/**=======delete function========== */ 
public function deleteOrder($id)
{
    Order::destroy($id);
    return redirect()->back();
}
public function deleteAppointment($id)
{
    try {
        Appointment::findOrFail($id)->delete();
        return redirect()->back();
    } catch (\Exception $e) {
        // handle the exception
    }
}
public function deleteMessage($id)
{
    try {
        $message = Message::findOrFail($id);
        $message->delete();
        return redirect()->back();
    } catch (\Exception $e) {
        report($e);
        return back()->with('error', 'Failed to delete message');
    }
}
public function deleteUser($id)
{
    try {
        User::destroy($id);
        return back();
    } catch (\Exception $e) {
        // Log the exception or handle it in an appropriate way
        return response()->json(['error' => 'Failed to delete user'], 500);
    }
}

public function deletePrescription($id){
    try {
        $prescription = Prescription::findOrFail($id);
        $prescription->delete();
        return redirect()->back();
    } catch (\Exception $e) {
        report($e);
        return back()->with('error', 'Failed to delete prescription');
    }
}



/**=======Create messages function========== */

public function createMessage()
{
    $users = User::all();
    return view('admin.messages.create')->with('users', $users);
}
public function send(Request $request)
{
    $request->validate([
        'subject' => 'required|string|max:255',
        'content' => 'required|string',
        'user_id' => 'required',
    ]); 

    Message::create([
        'sender_id' => auth()->id(),
        'recipient_id' => $request->input('user_id'),
        'subject' => $request->input('subject'),
        'content' => $request->input('content'),
    ]);
    return redirect()->route('admin.messages.index');
}

/**=======Create appointments function========== */
public function createAppointment()
{
    $users = User::all();
    return view('admin.appointments.create')->with('users', $users);
}
public function storeAppointment(Request $request)
{
    $request->validate([
        'user_id' => 'required',
        'input_date' => 'required',
        'radio_selection' => 'required|in:8:00 AM,10:00 AM,12:00 PM,2:00 PM,4:00 PM',
    ]);
    Appointment::create($request->all());
    return redirect()->route('admin.appointments.index');
}
/**=======Create Order function========== */
public function createOrder()
{
    $users = User::all();
    return view('admin.orders.create')->with('users', $users);
}
public function storeOrder(Request $request)
{
    $request->validate([
        'user_id' => 'required',
        'location' => 'required',
        'quantity' => 'required',
    ]);
    
    Order::create($request->all());
    return redirect()->route('admin.orders.index');
}
/**=======Create Prescription function========== */
public function createPrescription(){
    $users = User::all();
    return view('admin.prescriptions.create')->with('users', $users);
}
public function storePrescription(Request $request){
    $request->validate([
        'user_id' => 'required',
        'medication' => 'required|string|max:255',
        'instructions' => 'required|string',
        'dosage' => 'required|string',
        'frequency' => 'required|string',
    ]);
    $prescription = new Prescription();
    $prescription->user_id = $request->input('user_id');
    $prescription->medication = $request->input('medication');
    $prescription->instructions = $request->input('instructions');
    $prescription->dosage = $request->input('dosage');
    $prescription->frequency = $request->input('frequency');
    $prescription->save();
    return redirect()->route('admin.prescriptions.index');
}


/**=======Download PDF function========== */
public function downloadPDF($id){
    $prescription = Prescription::findOrFail($id);
    $pdf = PDF::loadView('prescription', compact('prescription'));
    return $pdf->download('prescription.pdf');
}





/**=======search function========== */
public function search(){
    $results = User::where('name', 'like', '%' . request('query') . '%')
    ->orWhere('email', 'like', '%' . request('query') . '%')
    ->get();
return response()->json($results);
}









}



