<?php

use App\Http\Controllers\ProfileController;
use App\Http\Controllers\AppointmentController;
use App\Http\Controllers\DashboardController;
use App\Http\Controllers\MessageController;
use App\Http\Controllers\AdminController;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\Auth\AuthenticatedSessionController;
use App\Http\Controllers\PrescriptionController;
use App\Models\Prescription;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider and all of them will
| be assigned to the "web" middleware group. Make something great!
|
*/


Route::get('/', function () {
    return view('welcome');
})->name('welcome');
Route::get('/about-us', function () {
    return view('about');
})->name('about-us');

/*
Route::middleware(['auth', 'verified'])->group(function () {
    Route::get('/dashboard', function () {
        return view('dashboard');
    })->name('dashboard');
*/


Route::middleware(['auth', 'verified'])->group(function () {
    Route::get('/dashboard', [DashboardController::class, 'show'])->name('dashboard');
    Route::post('/appointment/store', [AppointmentController::class, 'store'])->name('appointment.store');
    Route::get('/prescription/{id}', [PrescriptionController::class, 'index'])->name('prescription');
    Route::get('/pdf-download/{id}', [AdminController::class, 'downloadPDF'])->name('pdf-download');


    //#TODO : change this to show on the dashboard
    Route::get('/messages/sent', [MessageController::class, 'sent']); 
    Route::post('/messages/send', [MessageController::class,'send'])->name('message.send');
});

//
Route::prefix('admin')->middleware(['auth', 'checkUserRole'])->group(function() {
    Route::get('/', [AdminController::class, 'index'])->name('admin.index');

    Route::get('/orders', [AdminController::class, 'orders'])->name('admin.orders.index');
    Route::get('/orders/{id}/edit', [AdminController::class, 'editOrder'])->name('admin.orders.edit');
    Route::put('/orders/{id}/update', [AdminController::class, 'updateOrder'])->name('admin.orders.update');    
    Route::delete('/orders/{id}/delete', [AdminController::class, 'deleteOrder'])->name('admin.orders.delete');
    Route::get('/orders/create', [AdminController::class, 'createOrder'])->name('admin.orders.create');
    Route::post('orders/store',[AdminController::class, 'storeOrder'])->name('admin.orders.store');

//admin routes to handle appointments
    Route::get('/appointments', [AdminController::class, 'appointments'])->name('admin.appointments.index');
    Route::get('/appointments/{id}/edit', [AdminController::class, 'editAppointment'])->name('admin.appointments.edit');
    Route::put('/appointments/{id}/update', [AdminController::class, 'updateAppointment'])->name('admin.appointments.update');
    Route::delete('/appointments/{id}/delete', [AdminController::class, 'deleteAppointment'])->name('admin.appointments.delete');
    Route::get('appointments/create', [AdminController::class, 'createAppointment'])->name('admin.appointments.create');
    Route::post('appointments/store',[AdminController::class, 'storeAppointment'])->name('admin.appointments.store');

    //admin routes to handle messages
    Route::get('/messages', [AdminController::class, 'messages'])->name('admin.messages.index');
    Route::get('/messages/{id}/edit', [AdminController::class, 'editMessage'])->name('admin.messages.edit');
    Route::put('/messages/{id}/update', [AdminController::class, 'updateMessage'])->name('admin.messages.update');
    Route::delete('/messages/{id}/delete', [AdminController::class, 'deleteMessage'])->name('admin.messages.delete');
    //TODO:check this routes logic
    Route::get('messages/create', [AdminController::class, 'createMessage'])->name('admin.messages.create');
    Route::post('messages/create', [AdminController::class, 'send'])->name('admin.messages.send');

    //admin routes to handle users
    Route::get('/users', [AdminController::class, 'users'])->name('admin.users.index');
    Route::get('users/{id}', [AdminController::class, 'showUser'])->name('admin.users.show');
    Route::get('/users/{id}/edit', [AdminController::class, 'editUser'])->name('admin.users.edit');
    Route::put('/users/{id}/update', [AdminController::class, 'updateUser'])->name('admin.users.update');
    Route::delete('/users/{id}/delete', [AdminController::class, 'deleteUser'])->name('admin.users.delete');

   //admin routes to hande prescriptions
   Route::get('/prescriptions', [AdminController::class, 'prescriptions'])->name('admin.prescriptions.index');
   Route::get('/prescriptions/{id}/edit', [AdminController::class, 'editPrescription'])->name('admin.prescriptions.edit');
   Route::put('/prescriptions/{id}/update', [AdminController::class, 'updatePrescription'])->name('admin.prescriptions.update');
   Route::delete('/prescriptions/{id}/delete', [AdminController::class, 'deletePrescription'])->name('admin.prescriptions.delete');
   Route::get('prescriptions/create', [AdminController::class, 'createPrescription'])->name('admin.prescriptions.create');
   Route::post('prescriptions/store',[AdminController::class, 'storePrescription'])->name('admin.prescriptions.store');
   

    Route::get('logout', [AuthenticatedSessionController::class, 'destroy'])
                ->name('admin.logout');
    //search route
  Route::get('/search', [AdminController::class, 'search'])->name('admin.search');
  
});



Route::middleware('auth')->group(function () {
    Route::get('/profile', [ProfileController::class, 'edit'])->name('profile.edit');
    Route::patch('/profile', [ProfileController::class, 'update'])->name('profile.update');
    Route::delete('/profile', [ProfileController::class, 'destroy'])->name('profile.destroy');

});


Route::get('/eligibility-form', function () {
         return view('eligibilityform');
     });

require __DIR__.'/auth.php';
